try:
    from functools import cached_property as fast_property
except ImportError:
    fast_property = property  # support older python, though it will be less efficient

from social_core.backends.open_id_connect import OpenIdConnectAuth


class UMichOIDC(OpenIdConnectAuth):
    name = "umich-oidc"

    @fast_property
    def OIDC_ENDPOINT(self):
        return self.setting("ENDPOINT", "https://shibboleth.umich.edu")

    def get_remote_jwks_keys(self):
        keys = super().get_remote_jwks_keys()

        for key in keys:
            key.setdefault("alg", "RS256")

        return keys

    def auth_complete_credentials(self):
        return self.get_key_and_secret()
