# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['social_auth_umich',
 'social_auth_umich.django',
 'social_auth_umich.django.management',
 'social_auth_umich.django.management.commands']

package_data = \
{'': ['*']}

install_requires = \
['social-auth-core>=4.2.0,<5.0.0']

extras_require = \
{'django': ['Django>=3.2,<4.0', 'social-auth-app-django>=5.0.0,<6.0.0'],
 'openidconnect': ['python-jose>=3.3.0,<4.0.0'],
 'saml': ['python3-saml>=1.14.0,<2.0.0']}

setup_kwargs = {
    'name': 'social-auth-umich',
    'version': '0.2.0',
    'description': 'Python-social-auth backend for University of Michigan Shibboleth authentication',
    'long_description': '# University of Michigan Shibboleth Authentication for `python-social-auth`\n\nThis library contains backends and instructions for integrating python applications into\n[University of Michigan\'s Shibboleth single sign-on](https://its.umich.edu/accounts-access/shibboleth)\ninfrastructure.\n\n## Installation\n\nThe package is not currently available in a publicly accessible package repository.\nHowever, you can still install this package as an external git dependency from Github\nusing `pip` or similar tools.\n\n### Setting up an SSH Key with Github\n\nFollow the [Github instructions](https://docs.github.com/en/authentication/connecting-to-github-with-ssh) for configuring an SSH key for your account\n\n### Use directly in your active environment\n\nUsing `pip`, you can install this package directly from Github like the following:\n\n```shell\npip install git+ssh://git@github.com/academic-innovation/social-auth-umich.git@main#egg=social-auth-umich\n```\n\n### In Requirements files\n\nThese same format can be used within a `requirements.txt` file, which can be useful for containerized builds and deploys. E.g.\n\n```\nsocial-auth-umich @ git+ssh://git@github.com/academic-innovation/social-auth-umich.git@main\n```\n\n### Package Extras\n\nThere are three package extra definitions that can be used by the consuming project.\n\n<dl>\n    <dt>django</dt>\n    <dd>\n        Adds dependencies for Django >= 3.2, and an associated social-auth-app-django.\n    </dd>\n    <dt>saml</dt>\n    <dd>Adds dependency on <code>python3-saml</code></dd>\n    <dt>openidconnect</dt>\n    <dd>Adds JWT library dependencies</dd>\n</dl>\n\nThese are not crucial, but can be useful shortcuts for installing this library for your\nproject. For example, if this was being used with OIDC on a django project, you might\nset your requirements to be `social-auth-umich[django,openidconnect]`.\n\n## Protocol Options\n\nThere are\n[multiple options](https://its.umich.edu/accounts-access/shibboleth/protocol-options)\nfor authenticating users with Shibboleth at UM. This supports two of those methods:\n\n- Security Assertion Markup Language (SAML)\n- OpenID Connect (OIDC)\n\nSAML is supported directly by `python-social-auth`, and it\'s not strictly necessary to\ninstall this library to use it.\n\n## Registering an app with ITS\n\nRegardless of which protocol you choose, you must register your app by filling out the\n[Shibboleth Configuration Request Form](https://its.umich.edu/accounts-access/shibboleth/configuration-request-form).\nThe protocol you choose changes the information you need to give on that form. See the\ndetails for each protocol to see what information is necessary.\n\n## Using OIDC\n\nA Social Auth backend for OIDC is available as: `social_auth_umich.backends.UMichOIDC`.\n\n### Installation\n\nTo use as a dependency in your local project, you will either want to install this\npackage with its `openidconnect` extra, or `social-auth-core[openidconnect]`.\n\n### Information required for registration\n\nOIDC only requires two pieces of information: the Main URL of the application you are\nregistering (e.g. https://my-awesome-app.umich.edu/), and the redirect URI after a\nsuccessful authentication, which depends on your configuration below.\n\n### Configuration\n\nThere are three (two required, one optional) settings to configure for this backend.\n\n<dl>\n    <dt>UMICH_OIDC_KEY</dt>\n    <dd>The key given by UM IAM after registering the application</dd>\n    <dt>UMICH_OIDC_SECRET</dt>\n    <dd>The secret given by UM IAM after registering the application</dd>\n    <dt>UMICH_OIDC_ENDPOINT</dt>\n    <dd>\n        A protocol and hostname for the target OIDC endpoint, without a trailing slash.\n        By default, this is the production Shibboleth instance. For testing purposes,\n        you may point this to the staging instance (currently\n        "https://shib-idp-staging.dsc.umich.edu")\n    </dd>\n</dl>\n\n### Django example\n\nConfigure the project as described in the [`python-social-auth` documentation](https://python-social-auth.readthedocs.io/en/latest/configuration/django.html).\n\nAdd `social_auth_umich.backends.UMichOIDC` to the `AUTHENTICATION_BACKENDS`:\n\n```python\nAUTHENTICATION_BACKENDS = (\n    "social_auth_umich.backends.UMichOIDC",\n    "django.contrib.auth.backends.ModelBackend",\n)\n```\n\nFor convience, you may wish to add `social_auth_umich.django` to the list of\n`INSTALLED_APPS`. By doing this, you can use the `umich_oidc_redirect_path` management\ncommand to get the path when registering the app. E.g.\n\n```shell\n$ python manage.py umich_oidc_redirect_path\n/social/complete/umich-oidc/\n$\n```\n\nSet the necessary configuration settings as defined above:\n\n```python\nSOCIAL_AUTH_UMICH_OIDC_KEY = "<key>"\nSOCIAL_AUTH_UMICH_OIDC_SECRET = "<secret>"\n```\n\nIn your templates, you can link to the backend URL using a link similar to the following:\n\n```html\n<a href="{% url \'social:begin\' \'umich-oidc\' %}">Sign in</a>\n```\n\n## Using SAML\n\n> SAML is currently untested. If there are inaccuracies, please create a Merge Request.\n\nThe existing `social_auth.backends.saml.SAMLAuth` is enough to support SAML authentication\nwith UM Shibboleth.\n\n### Installation\n\nEnsure that the `python-social-auth` SAML dependencies are installed. The backend\nrequires `python3-saml`, which in turn requires a number of system libraries to\nfunction, namely `libxml2` and `xmlsec`. Ensure that these are available on your system\nbefore installing the python libraries.\n\n#### Using Debian-based Linux distributions\n\n```shell\n$ apt-get install libxml2-dev libxmlsec1-dev libxmlsec1-openssl\n```\n\n#### Using Red Hat-based Linux distributions\n\n> TODO\n\n#### Using Homebrew (on macOS)\n\nIf you have [Homebrew](https://brew.sh/) installed already, you can use it by executing\nthe following command:\n\n```shell\n$ brew install libxml2 libxmlsec1 pkg-config\n```\n\n### Creating certificates\n\nTo establish trust with the Shibboleth IdP, your application must have its own set of\nX.509 certificates to signing and validating communications. One way to create those\ncertificates is using `openssl` to generate a pair of self-signed certificates, e.g.:\n\n```shell\n$ openssl req -x509 -newkey rsa:4096 -keyout certs/key.pem -out certs/cert.pem -nodes -days 1096\n```\n\nThe `cert.pem` contains the public key for the service provider. This is what you will\nshare with ITS. The `key.pem` contains the private key for this service provider.\n**DO NOT SHARE THIS KEY**\n\n### Information required for registration\n\nITS will request some information about the site\'s Entity ID (a URL to identify the\nservice, defined in your project\'s settings), the site\'s domain/hostname, and a URL to\nan XML Metadata file. `python-social-auth` can generate this for us, as shown in the\nDjango example below. When asked for the "Connection method", you can choose "Other".\n\n### Configuration\n\nSAML configuration requires a number of settings, and it\'s best to consult the\n[`python-social-auth` SAML documentation](https://python-social-auth.readthedocs.io/en/latest/backends/saml.html#required-configuration).\nSome of the configuration matter is available in `social_auth_umich.saml`, which should\nsimplify some of the contents. When setting up the list of IdPs for your site, you can\nuse `social_auth_umich.saml.UMICH_IDP` (or\n`social_auth_umich.saml.UMICH_STAGING_IDP`, for attaching to UM’s staging IdP) as\nthe basis for your `SOCIAL_AUTH_SAML_ENABLED_IDPS`. For example:\n\n```python\nfrom social_auth_umich.saml import UMICH_IDP\n\nSOCIAL_AUTH_SAML_ENABLED_IDPS = {\n    "umich": UMICH_IDP,\n}\n```\n\n### SAML Attributes\n\nThis library includes some useful definitions for handling the parsing and mapping of\nSAML attributes in the authentication response. The\n`social_auth_umich.saml.SAMLAttributes` namespace could be helpful when customizing your\n[`python-social-auth` authentication pipeline](https://python-social-auth.readthedocs.io/en/latest/pipeline.html#authentication-pipeline). These are based on the Shibboleth\nattributes [documented by ITS](https://documentation.its.umich.edu/node/262/).\n\nDuring the pipeline execution, the `details` dictionary is populated with a set of\nattributes defined in the IdP configuration. The default IdP definitions include\nattribute mapping for the `details` dictionary as follows:\n\n<table>\n  <thead>\n    <tr>\n      <th><code>user_details</code> field</th>\n      <th>SAML attribute name</th>\n      <th><code>SAMLAttributes</code> name</th>\n    </tr>\n  </thead>\n  <tbody>\n    <tr><td>full_name</td><td>displayName</td><td>MCOMMUNITY_NAME</td></tr>\n    <tr><td>first_name</td><td>givenName</td><td>FIRST_NAME</td></tr>\n    <tr><td>last_name</td><td>sn</td><td>LAST_NAME</td></tr>\n    <tr><td>username</td><td>eduPersonPrincipalName</td><td>PRINCIPAL_NAME</td></tr>\n    <tr><td>email</td><td>mail</td><td>EMAIL</td></tr>\n  </tbody>\n</table>\n\nIn addition, the `python-social-auth` "User ID" (`attr_permanent_user_id`) for the\nresponse is mapped to `SAMLAttributes.PRINCIPAL_NAME`.\n\nYou can use the `*_BASE` dictionaries and mix-in the custom attribute mapping you need.\nFor instance, if you wanted to use the user\'s uniqname for their username (and you had\nthe `uid` SAML attribute granted):\n\n```python\nSOCIAL_AUTH_SAML_ENABLED_IDPS = {\n    "umich": {\n        **UMICH_IDP_BASE,\n        "attr_username": SAMLAttributes.UNIQNAME,\n    },\n}\n# Or, if you\'re targeting Python 3.9 or later, you can use Dictionary Union operations\nSOCIAL_AUTH_SAML_ENABLED_IDPS = {\n    "umich": UMICH_IDP_BASE | {\n        "attr_username": SAMLAttributes.UNIQNAME,\n    },\n}\n```\n\nIf you want to pull any SAML attribute values out of the SAML response during your own\npipeline stages, you can use `SAMLAttributes` to pull the information you need.\n\n```python\n\ndef user_university_affiliation(backend, user, response, *args, **kwargs):\n    if backend.name == "saml" and response["idp_name"] == "umich":\n        um_affiliation = response["attributes"].get(SAMLAttributes.AFFILIATION, [])\n        if \'student\' in um_affiliation:\n            ...\n```\n\nIf there are values you want to save for later, you can use the `extra_data` feature in\n`python-social-auth` to automatically store them.  You can do so by defining the setting\nas mentioned in the\n[`python-social-auth` SAML docs](https://python-social-auth.readthedocs.io/en/latest/backends/saml.html#advanced-settings),\ne.g.:\n\n```python\nSOCIAL_AUTH_SAML_EXTRA_DATA = [\n    (SAMLAttributes.AFFILIATION, "affiliation"),\n    (SAMLAttributes.EMPLOYEE_NUMBER, "UMID"),\n]\n```\n\n> NOTE: the `extra_data` mapping above is for all SAML backends, not UM specifically.\n\n### Django Example\n\nConfigure the project as described in the [`python-social-auth` documentation](https://python-social-auth.readthedocs.io/en/latest/configuration/django.html).\n\nAdd `social_auth.backends.saml.SAMLAuth` to the `AUTHENTICATION_BACKENDS`:\n\n```python\nAUTHENTICATION_BACKENDS = (\n    "social_auth.backends.saml.SAMLAuth",\n    "django.contrib.auth.backends.ModelBackend",\n)\n```\n\nSet the required `SOCIAL_AUTH_SAML_*` configuration values, as described in the\nconfiguration section above.\n\n```python\nSOCIAL_AUTH_SAML_SP_ENTITY_ID = "https://my-awesome-app.umich.edu/shibboleth"\nSOCIAL_AUTH_SAML_SP_PUBLIC_CERT = "<contents of cert.pem>"\n# or read the contents of a file SOCIAL_AUTH_SAML_SP_PUBLIC_CERT = open("./certs/cert.pem", \'r\').read()\n# or read the contents of an env var SOCIAL_AUTH_SAML_SP_PUBLIC_CERT = os.environ[\'SAML_PUBLIC_KEY\']\nSOCIAL_AUTH_SAML_SP_PRIVATE_KEY = "<contents of key.pem>"\n# or alternatives such as the above\nSOCIAL_AUTH_SAML_ORG_INFO = {\n    "en-US": {\n        "name": "my-awesome-app",\n        "displayname": "My Awesome App",\n        "url": "https://my-awesome-app.umich.edu/",\n    },\n}\nSOCIAL_AUTH_SAML_SUPPORT_CONTACT = {\n    "givenName": "Gerald R. Ford, Jr.",\n    "emailAddress": "prez38@umich.edu",\n}\nSOCIAL_AUTH_SAML_TECHNICAL_CONTACT = {\n    "givenName": "James Earl Jones",\n    "emailAddress": "darth-vader@umich.edu",\n}\nSOCIAL_AUTH_ENABLED_IDPS = {\n    "umich": UMICH_IDP,\n}\n```\n\nTo help with our metadata generation, you can mount a view in\n`social_auth_umich.django.views` to your urls.\n\nIn `urls.py`:\n\n```\nfrom django.urls import re_path\nfrom social_auth_umich.django.views import saml_metadata_view\n\n\nurlpatterns = [\n    path(\'\', include("social_django.urls", namespace="social")),\n    re_path(r"^metadata\\.xml$", saml_metadata_view),\n    ...\n]\n```\n\nYou can then give "https://my-awesome-app.umich.edu/metadata.xml" as the "Metadata URL"\nwhen registering your Service with ITS.\n\nFor convenience, there\'s also a `saml_begin_url` function in\n`social_auth_umich.django.utils`, that makes generating a hyperlink within your project\nsimple. E.g.\n\n```python\nfrom django.shortcuts import render\nfrom social_auth_umich.django.utils import saml_begin_url\n\n\ndef my_fancy_view(request):\n    context = {\n        "login_with_umich_url": saml_begin_url(),\n    }\n    return render(request, "fancy.html", context)\n\n# Or, with a Class-based View\nclass MyFancyView(TemplateView):\n    template_name = "fancy.html"\n\n    def get_context_data(self, **kwargs):\n        context = super().get_context_data(**kwargs)\n        context["login_with_umich_url"] = saml_begin_url()\n        return context\n```\n\nIn `fancy.html`:\n```html\n<a href="{{ login_with_umich_url }}">Log in with U-M</a>\n```\n\n## Development\n\nThis package is managed with [poetry](https://python-poetry.org/). All python assets\nare formatted with [black](https://black.readthedocs.io/en/stable/) and checked with\n[flake8](https://flake8.pycqa.org/). Python 3.6 or greater is required.\n',
    'author': "Dennis O'Reilly",
    'author_email': 'doreilly@umich.edu',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7.7,<4.0.0',
}


setup(**setup_kwargs)
